@@ -64,5 +64,19 @@ def thag(ras1,ras2,hyp):
         return (hyp**2-ras1**2)**0.5
     elif hyp == "x" and ras1!= "x" and ras2 !="x":
         return (ras1**2+ras2**2)**0.5
+    else:
+        return "请检查参数"
+
+#和差问题
+def hecha(he,cha,first,second):
+    if he == "x" and cha != "x" and first != "x" and second != "x":
+        return first + second
+    elif he != "x" and cha == "x" and first != "x" and second != "x":
+        if first >= second:
+            return first - second
+        else:
+            return second - first
+    elif he != "x" and cha != "x" and first == "x" and second == "x":
+        return (he+cha)/2,(he-cha)/2
     else:
         return "请检查参数"
\ No newline at end of file
